@@ -250,7 +250,8 @@ def main(list_ids, model, contact_server, raw_data_id, show_raw):
                 print("hwrt version: %s" % hwrt.__version__)
                 display_data(handwriting.raw_data_json,
                              handwriting.formula_id,
-                             model)
+                             model,
+                             show_raw)
 
 if __name__ == '__main__':
     args = get_parser().parse_args()
